from datetime import datetime
import sqlite3
from optparse import OptionParser
# from email.mime.text import MIMEText
# from email.utils import formatdate 

EL_PATH = "/home/user/.rtcom-eventlogger/el-v1.db"

class Events:
    _select = "SELECT E.start_time, E.is_read, E.outgoing, E.remote_uid, R.remote_name, E.local_uid, E.local_name, E.free_text"
    _from = "FROM Events E, Remotes R, EventTypes T"
    _where = "WHERE R.remote_uid=E.remote_uid AND E.local_uid=R.local_uid AND T.name='RTCOM_EL_EVENTTYPE_SMS_MESSAGE' AND E.event_type_id=T.id"
    _order = "ORDER BY start_time ASC"
    _like = " "
    
    def __init__(self, db=EL_PATH):
        self._conn = sqlite3.connect(db)
    
    def all(self):
        self._cur = self._conn.cursor()
        self._cur.execute(self._select + " " + self._from + " " + self._where + self._like + " " + self._order)
        return self
    
    def inbox(self):
        self._cur = self._conn.cursor()
        query = self._select + " " + self._from + " " + self._where + " AND E.outgoing = 0 " + self._like + " " + self._order
        print query
        self._cur.execute(self._select + " " + self._from + " " + self._where + " AND E.outgoing = 0 " + self._like + " " + self._order)
        return self
    
    def unread(self):
        self._cur = self._conn.cursor()
        self._cur.execute(self._select + " " + self._from + " " + self._where + " AND E.is_read = 0 " + self._like + " " + self._order)
        return self
    
    def sent(self):
        self._cur = self._conn.cursor()
        self._cur.execute(self._select + " " + self._from + " " + self._where + " AND E.outgoing = 1 " + self._like + " " + self._order)
        return self
    
    def filter(self, filter=None):
        if filter is None:
            self._like = " "
        else:
            self._like = " AND R.remote_name LIKE '%" + filter + "%' "
    
    def __iter__(self):
        for row in self._cur:
            yield row

if __name__ == "__main__":
    parser = OptionParser()
    parser.add_option("-a", "--all",
                      action="store_true", dest="all", default=False,
                      help="display all messages")
    parser.add_option("-i", "--inbox",
                      action="store_true", dest="inbox", default=False,
                      help="display only received messages")
    parser.add_option("-s", "--sent",
                      action="store_true", dest="sent", default=False,
                      help="display only sent messages")
    parser.add_option("-u", "--unread",
                      action="store_true", dest="unread", default=True,
                      help="display only unread messages")
    
    (options, args) = parser.parse_args()
    
    events = Events()
    
    if len(args) > 0:
        events.filter(args[0])
    
    if options.all:
        events.all()
    elif options.inbox:
        events.inbox()
    elif options.sent:
        events.sent()
    elif options.unread:
        events.unread()
    
    for sms in events:
        dt = datetime.fromtimestamp(sms[0])
        is_read = sms[1]
        outgoing = sms[2]
        remote_uid = sms[3]
        remote_name = sms[4]
        local_uid = sms[5]
        local_name = sms[6]
        content = sms[7]
        
        if remote_name == remote_uid or remote_name is None:
            remote = remote_uid
        else:
            remote = remote_name + " " + remote_uid
            
        if outgoing:
            print u"To:", remote.encode('utf-8')
        else:
            print u"From:", remote.encode('utf-8')
        
        print u"Date:", str(dt).encode('utf-8')
        print content.encode('utf-8')
        print
    
        # dt = formatdate(sms[0])
    # msg = MIMEText(content, "plain", "UTF-8")
    # if outgoing:
    #     msg['To'] = remote
    # else:
    #     msg['From'] = remote
    # msg['Subject'] = content[0:64]
    # msg['Date'] = dt

    # print msg.as_string()
